"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.creator = exports.messages = void 0;
const path_1 = __importDefault(require("path"));
const FILE_NAME_DOTENV = ".env";
exports.messages = {
    FOUND_DOTENV_FILE: {
        en: () => "found .env file",
        ja: () => ".env ファイルがみつかりました",
    },
};
const isDotenvFile = (filePath) => {
    const { name, ext } = path_1.default.parse(filePath);
    const fileName = `${name}${ext}`;
    return fileName === FILE_NAME_DOTENV;
};
exports.creator = {
    messages: exports.messages,
    meta: {
        id: "@secretlint/secretlint-rule-no-dotenv",
        recommended: true,
        type: "scanner",
        supportedContentTypes: ["text"],
        docs: {
            url: "https://github.com/secretlint/secretlint/blob/master/packages/%40secretlint/secretlint-rule-no-dotenv/README.md",
        },
    },
    create(context) {
        const t = context.createTranslator(exports.messages);
        return {
            file(source) {
                if (!source.filePath) {
                    return;
                }
                if (isDotenvFile(source.filePath)) {
                    context.report({
                        message: t("FOUND_DOTENV_FILE"),
                        range: [0, source.content.length],
                    });
                }
            },
        };
    },
};
exports.default = exports.creator;
//# sourceMappingURL=index.js.map